@@ -30,15 +30,13 @@ StationsPluginFactoryBelgium::id() const
 QString
 StationsPluginFactoryBelgium::name() const
 {
-  return QString::fromUtf8("Réseaux Belges - Authors:"
-			   "Patrick Installé <PatrickInstalle@P-Installe.be>,"
-			   "Corentin Chary <corentin.chary@gmail.com>");
+  return QString::fromUtf8("Réseaux Belges");
 }
 
 QIcon
 StationsPluginFactoryBelgium::icon() const
 {
-  return QIcon(":/belgium/bike.png");
+  return QIcon(":/belgium/be.png");
 }
 
 QList < StationsPlugin * >
