@@ -23,9 +23,9 @@
 #include "amiens_p.h"
 
 StationsPluginAmiens::StationsPluginAmiens(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateAmiens();
+  d = new StationsPluginSimplePrivateAmiens();
 }
 
 StationsPluginAmiens::~StationsPluginAmiens()
