@@ -30,15 +30,13 @@ StationsPluginFactoryJapan::id() const
 QString
 StationsPluginFactoryJapan::name() const
 {
-  return QString::fromUtf8("Japan - Authors:"
-			   "Patrick Installé <PatrickInstalle@P-Installe.be>,"
-			   "Corentin Chary <corentin.chary@gmail.com>");
+  return QString::fromUtf8("Japan");
 }
 
 QIcon
 StationsPluginFactoryJapan::icon() const
 {
-  return QIcon(":/japan/bike.png");
+  return QIcon(":/japan/jp.png");
 }
 
 QList < StationsPlugin * >
