@@ -23,9 +23,9 @@
 #include "toyama_p.h"
 
 StationsPluginToyama::StationsPluginToyama(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateToyama();
+  d = new StationsPluginSimplePrivateToyama();
 }
 
 StationsPluginToyama::~StationsPluginToyama()
