@@ -21,6 +21,7 @@
 #include "factory.h"
 #include "seville.h"
 #include "santander.h"
+#include "barcelone.h"
 
 QString
 StationsPluginFactorySpain::id() const
@@ -31,15 +32,13 @@ StationsPluginFactorySpain::id() const
 QString
 StationsPluginFactorySpain::name() const
 {
-  return QString::fromUtf8("Spain - Authors:"
-			   "Patrick Installé <PatrickInstalle@P-Installe.be>,"
-			   "Corentin Chary <corentin.chary@gmail.com>");
+  return QString::fromUtf8("Spain");
 }
 
 QIcon
 StationsPluginFactorySpain::icon() const
 {
-  return QIcon(":/spain/bike.png");
+  return QIcon(":/spain/es.png");
 }
 
 QList < StationsPlugin * >
@@ -49,6 +48,7 @@ StationsPluginFactorySpain::stations(QObject *parent)
 
   ret << new StationsPluginSeville(parent);
   ret << new StationsPluginSantander(parent);
+  ret << new StationsPluginBarcelone(parent);
   return ret;
 }
 
